@@ -1,6 +1,12 @@
+// SPDX-FileCopyrightText: 2024 Christina Sørensen
+// SPDX-License-Identifier: EUPL-1.2
+//
+// SPDX-FileCopyrightText: 2023-2024 Christina Sørensen, eza contributors
+// SPDX-FileCopyrightText: 2014 Benjamin Sago
+// SPDX-License-Identifier: MIT
 use std::io::{self, Write};
 
-use ansiterm::ANSIStrings;
+use nu_ansi_term::AnsiStrings as ANSIStrings;
 
 use crate::fs::filter::FileFilter;
 use crate::fs::File;
